@@ -48,6 +48,8 @@ class MikrotikApiClient:
             self._ssl = ssl.create_default_context()
             self._ssl.check_hostname = False
             self._ssl.verify_mode = ssl.CERT_NONE
+        # map to filter special chars in api keys
+        self.trans_map = str.maketrans('-', '_', './')
 
     async def _get_results_data(self,
                                 cmd,
@@ -75,7 +77,6 @@ class MikrotikApiClient:
             elif not r or r[0] != '!re':
                 print('unexpected result for {}: {}'.format(self.host, r))
                 raise RuntimeError('unexpected result')
-                continue
             row = {x[0][1:]: x[1] for x in r[1].items()}
             if include_disabled:
                 results.append(row)
@@ -84,7 +85,12 @@ class MikrotikApiClient:
                     results.append(row)
         if results:
             keys = list(sorted(set(itertools.chain.from_iterable(results))))
-            fields = [x.replace('.', '').replace('-', '_') for x in keys]
+            # keys cannot include special chars '/' , '.' or started with digit
+            fields = [
+                f"x_{str(x).translate(self.trans_map)}"
+                if str(x[0]).isdigit() else str(x).translate(self.trans_map)
+                for x in keys
+            ]
             fields = [x.upper() if iskeyword(x) else x for x in fields]
             nt = namedtuple('Row', fields)
         return [nt(*[x.get(k) for k in keys]) for x in results]
