@@ -2170,6 +2170,17 @@ class NetworkElement:
         else:
             self.pb.imsi = value
 
+    @property
+    def admin_disabled(self):
+        return self.pb.admin_disabled if self.pb.HasField('admin_disabled') else None
+
+    @admin_disabled.setter
+    def admin_disabled(self, value):
+        if value is None:
+            self.pb.ClearField('admin_disabled')
+        else:
+            self.pb.admin_disabled = value
+
 
 class NetworkElementUpdate:
 
