@@ -373,6 +373,12 @@ class TestNetworkElementUpdate(unittest.TestCase):
         ne.imsi = None
         self.assertEqual(ne.imsi, None)
 
+        self.assertEqual(ne.admin_disabled, None)
+        ne.admin_disabled = True
+        self.assertEqual(ne.admin_disabled, True)
+        ne.admin_disabled = None
+        self.assertEqual(ne.admin_disabled, None)
+
         # Interface
         intf = ne.interfaces.add()
         intf.id = '1'
